.. _bluegraph_downstream_ref:

`bluegraph.downstream` package
------------------------------


Data structures
^^^^^^^^^^^^^^^


.. automodule:: bluegraph.downstream.data_structures
	:members:



Similarity
^^^^^^^^^^^


.. automodule:: bluegraph.downstream.similarity
	:members:


Node classification
^^^^^^^^^^^^^^^^^^^


.. automodule:: bluegraph.downstream.node_classification
	:members:



Edge prediction
^^^^^^^^^^^^^^^


.. automodule:: bluegraph.downstream.link_prediction
	:members:
